From 384a8f108e3de0e2475d4267732b0f3ffabb7541 Mon Sep 17 00:00:00 2001
From: xue <>
Date: Wed, 11 Jan 2006 00:16:33 +0000
Subject:
---
framework/Web/UI/TControl.php | 26 +++++---------------------
1 file changed, 5 insertions(+), 21 deletions(-)
(limited to 'framework/Web/UI/TControl.php')
diff --git a/framework/Web/UI/TControl.php b/framework/Web/UI/TControl.php
index 225b6b32..99af06d1 100644
--- a/framework/Web/UI/TControl.php
+++ b/framework/Web/UI/TControl.php
@@ -999,7 +999,6 @@ class TControl extends TComponent
*/
protected function initRecursive($namingContainer=null)
{
- $this->ensureChildControls();
if($this->getHasControls())
{
if($this instanceof INamingContainer)
@@ -1056,6 +1055,7 @@ class TControl extends TComponent
{
if($this->getVisible(false))
{
+ $this->ensureChildControls();
$this->onPreRender(null);
if($this->getHasControls())
{
@@ -1739,8 +1739,8 @@ class TBroadcastEventParameter extends TEventParameter
*
* TCommandEventParameter encapsulates the parameter data for Command
* event of button controls. You can access the name of the command via
* Name property, and the parameter carried with the command via
* Parameter property.
*
* @author Qiang Xue
* @version $Revision: $ $Date: $
@@ -1766,34 +1766,18 @@ class TCommandEventParameter extends TEventParameter
/**
* @return string name of the command
*/
- public function getName()
+ public function getCommandName()
{
return $this->_name;
}
- /**
- * @param string name of the command
- */
- public function setName($value)
- {
- $this->_name=$value;
- }
-
/**
* @return string parameter of the command
*/
- public function getParameter()
+ public function getCommandParameter()
{
return $this->_param;
}
-
- /**
- * @param string parameter of the command
- */
- public function setParameter($value)
- {
- $this->_param=$value;
- }
}
?>
\ No newline at end of file
@@ -1739,8 +1739,8 @@ class TBroadcastEventParameter extends TEventParameter
* TCommandEventParameter encapsulates the parameter data for Command
* event of button controls. You can access the name of the command via
- * Name property, and the parameter carried with the command via
- * Parameter property.
+ * {@link getCommandName CommandName} property, and the parameter carried
+ * with the command via {@link getCommandParameter CommandParameter} property.
*
* @author Qiang Xue
--
cgit v1.2.3